@@ -23,6 +23,18 @@
 //!
 //! Low-level input-output routines.
 
+// These routines fail in principle when 'read' or 'write' are interrupted 
+// MAX_RESTART_AT_INTERRUPT times, for instance by SIGALRM.
+//
+// On platforms that support it, SIGALRM is used to implement a CPU time out 
+// on a running Algol 68 program. 
+//
+// The SIGALRM handler however implements BSD type restarting of primitive
+// system call interupted by it, which includes 'read' and 'write'. 
+// Consider however that non-responsive devices could make a68g 'hang'. 
+// In that case, specify option NORESTART, and SIGALRM will interrupt IO.
+// Current settings make these routines fail after 10 minutes of trying.
+
 #include "a68g.h"
 #include "a68g-prelude.h"
 
@@ -148,7 +160,7 @@ void io_write_string (FILE_T f, const char *z)
 ssize_t io_read (FILE_T fd, void *buf, size_t n)
 {
   size_t to_do = n;
-  int restarts = 0;
+  int retry = 0;
   char *z = (char *) buf;
   while (to_do > 0) {
     #if defined (BUILD_WIN32)
@@ -164,7 +176,7 @@ ssize_t io_read (FILE_T fd, void *buf, size_t n)
       if (errno == EINTR) {
 // interrupt, retry.
         bytes_read = 0;
-        if (restarts++ > MAX_RESTART) {
+        if (++retry > MAX_INTERRUPT_RESTART) {
           return -1;
         }
       } else {
@@ -185,7 +197,7 @@ ssize_t io_read (FILE_T fd, void *buf, size_t n)
 ssize_t io_write (FILE_T fd, const void *buf, size_t n)
 {
   size_t to_do = n;
-  int restarts = 0;
+  int retry = 0;
   char *z = (char *) buf;
   while (to_do > 0) {
     ssize_t bytes_written;
@@ -195,7 +207,7 @@ ssize_t io_write (FILE_T fd, const void *buf, size_t n)
       if (errno == EINTR) {
 // interrupt, retry.
         bytes_written = 0;
-        if (restarts++ > MAX_RESTART) {
+        if (++retry > MAX_INTERRUPT_RESTART) {
           return -1;
         }
       } else {
@@ -214,7 +226,7 @@ ssize_t io_write (FILE_T fd, const void *buf, size_t n)
 ssize_t io_read_conv (FILE_T fd, void *buf, size_t n)
 {
   size_t to_do = n;
-  int restarts = 0;
+  int retry = 0;
   char *z = (char *) buf;
   while (to_do > 0) {
     #if defined (BUILD_WIN32)
@@ -230,7 +242,7 @@ ssize_t io_read_conv (FILE_T fd, void *buf, size_t n)
       if (errno == EINTR) {
 // interrupt, retry.
         bytes_read = 0;
-        if (restarts++ > MAX_RESTART) {
+        if (++retry > MAX_INTERRUPT_RESTART) {
           return -1;
         }
       } else {
@@ -251,7 +263,7 @@ ssize_t io_read_conv (FILE_T fd, void *buf, size_t n)
 ssize_t io_write_conv (FILE_T fd, const void *buf, size_t n)
 {
   size_t to_do = n;
-  int restarts = 0;
+  int retry = 0;
   char *z = (char *) buf;
   while (to_do > 0) {
     ssize_t bytes_written;
@@ -261,7 +273,7 @@ ssize_t io_write_conv (FILE_T fd, const void *buf, size_t n)
       if (errno == EINTR) {
 // interrupt, retry.
         bytes_written = 0;
-        if (restarts++ > MAX_RESTART) {
+        if (++retry > MAX_INTERRUPT_RESTART) {
           return -1;
         }
       } else {
