@@ -36,8 +36,8 @@
 char *a68g_dirname (char *src)
 {
   size_t len = strlen (src) + 1;
-  char *cpy = (char *) get_fixed_heap_space (len + 1);
-  char *dst = (char *) get_fixed_heap_space (len + 1);
+  char *cpy = (char *) get_heap_space (len + 1);
+  char *dst = (char *) get_heap_space (len + 1);
   ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   a68g_bufcpy (cpy, src, len);
@@ -50,8 +50,8 @@ char *a68g_dirname (char *src)
 char *a68g_basename (char *src)
 {
   size_t len = strlen (src) + 1;
-  char *cpy = (char *) get_fixed_heap_space (len + 1);
-  char *dst = (char *) get_fixed_heap_space (len + 1);
+  char *cpy = (char *) get_heap_space (len + 1);
+  char *dst = (char *) get_heap_space (len + 1);
   ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   a68g_bufcpy (cpy, src, len);
@@ -82,7 +82,7 @@ static char *win32_realpath (char *name, char *resolved)
     return NO_TEXT;
   }
   if (resolved == NO_TEXT) {
-    res = (char *) get_fixed_heap_space (PATH_MAX + 1);
+    res = (char *) get_heap_space (PATH_MAX + 1);
     if (res == NO_TEXT) {
       return NO_TEXT;
     }
@@ -97,7 +97,7 @@ static char *win32_realpath (char *name, char *resolved)
     struct stat st;
     if (stat (res, &st) < 0) { // Should be 'lstat', but mingw does not have that.
       if (resolved == NO_TEXT) {
-        free (res);
+        a68g_free (res);
         return NO_TEXT;
       }
     }
@@ -149,10 +149,10 @@ char *a68g_relpath (char *p1, char *p2, char *fn)
   #endif
   if (r != NO_TEXT) {
     size_t len = strlen (r) + 1;
-    char *rc = (char *) get_fixed_heap_space (len);
+    char *rc = (char *) get_heap_space (len);
     ABEND (rc == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
     a68g_bufcpy (rc, r, len);
-    free (r);
+    a68g_free (r);
     return rc;
   } else {
     return NO_TEXT;
