@@ -34,19 +34,19 @@ static void push_grep_ret (NODE_T * p, int ret)
 {
   switch (ret) {
   case 0: {
-      PUSH_VALUE (p, 0, A68_INT);
+      PUSH_VALUE (p, 0, A68G_INT);
       return;
     }
   case REG_NOMATCH: {
-      PUSH_VALUE (p, 1, A68_INT);
+      PUSH_VALUE (p, 1, A68G_INT);
       return;
     }
   case REG_ESPACE: {
-      PUSH_VALUE (p, 3, A68_INT);
+      PUSH_VALUE (p, 3, A68G_INT);
       return;
     }
   default: {
-      PUSH_VALUE (p, 2, A68_INT);
+      PUSH_VALUE (p, 2, A68G_INT);
       return;
     }
   }
@@ -99,14 +99,14 @@ int grep_in_string (char *pat, char *str, int *start, int *end)
 
 void genie_grep_in_string (NODE_T * p)
 {
-  A68_REF ref_pat, ref_beg, ref_end, ref_str;
+  A68G_REF ref_pat, ref_beg, ref_end, ref_str;
   POP_REF (p, &ref_end);
   POP_REF (p, &ref_beg);
   POP_REF (p, &ref_str);
   POP_REF (p, &ref_pat);
-  A68_REF row = *(A68_REF *) & ref_str;
+  A68G_REF row = *(A68G_REF *) & ref_str;
   CHECK_INIT (p, INITIALISED (&row), M_ROWS);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
   reset_transput_buffer (PATTERN_BUFFER);
   reset_transput_buffer (STRING_BUFFER);
@@ -126,7 +126,7 @@ void genie_grep_in_string (NODE_T * p)
   regmatch_t *matches = a68g_alloc ((size_t) (nmatch * SIZE_ALIGNED (regmatch_t)), __func__, __LINE__);
   if (nmatch > 0 && matches == NULL) {
     ret = 2;
-    PUSH_VALUE (p, ret, A68_INT);
+    PUSH_VALUE (p, ret, A68G_INT);
     regfree (&compiled);
     return;
   }
@@ -146,12 +146,12 @@ void genie_grep_in_string (NODE_T * p)
     }
   }
   if (!IS_NIL (ref_beg)) {
-    A68_INT *i = DEREF (A68_INT, &ref_beg);
+    A68G_INT *i = DEREF (A68G_INT, &ref_beg);
     STATUS (i) = INIT_MASK;
     VALUE (i) = (int) (RM_SO (&(matches[max_k]))) + (int) (LOWER_BOUND (tup));
   }
   if (!IS_NIL (ref_end)) {
-    A68_INT *i = DEREF (A68_INT, &ref_end);
+    A68G_INT *i = DEREF (A68G_INT, &ref_end);
     STATUS (i) = INIT_MASK;
     VALUE (i) = (int) (RM_EO (&(matches[max_k]))) + (int) (LOWER_BOUND (tup)) - 1;
   }
@@ -163,14 +163,14 @@ void genie_grep_in_string (NODE_T * p)
 
 void genie_grep_in_substring (NODE_T * p)
 {
-  A68_REF ref_pat, ref_beg, ref_end, ref_str;
+  A68G_REF ref_pat, ref_beg, ref_end, ref_str;
   POP_REF (p, &ref_end);
   POP_REF (p, &ref_beg);
   POP_REF (p, &ref_str);
   POP_REF (p, &ref_pat);
-  A68_REF row = *(A68_REF *) & ref_str;
+  A68G_REF row = *(A68G_REF *) & ref_str;
   CHECK_INIT (p, INITIALISED (&row), M_ROWS);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
   reset_transput_buffer (PATTERN_BUFFER);
   reset_transput_buffer (STRING_BUFFER);
@@ -190,7 +190,7 @@ void genie_grep_in_substring (NODE_T * p)
   regmatch_t *matches = a68g_alloc ((size_t) (nmatch * SIZE_ALIGNED (regmatch_t)), __func__, __LINE__);
   if (nmatch > 0 && matches == NULL) {
     ret = 2;
-    PUSH_VALUE (p, ret, A68_INT);
+    PUSH_VALUE (p, ret, A68G_INT);
     regfree (&compiled);
     return;
   }
@@ -210,12 +210,12 @@ void genie_grep_in_substring (NODE_T * p)
     }
   }
   if (!IS_NIL (ref_beg)) {
-    A68_INT *i = DEREF (A68_INT, &ref_beg);
+    A68G_INT *i = DEREF (A68G_INT, &ref_beg);
     STATUS (i) = INIT_MASK;
     VALUE (i) = (int) (RM_SO (&(matches[max_k]))) + (int) (LOWER_BOUND (tup));
   }
   if (!IS_NIL (ref_end)) {
-    A68_INT *i = DEREF (A68_INT, &ref_end);
+    A68G_INT *i = DEREF (A68G_INT, &ref_end);
     STATUS (i) = INIT_MASK;
     VALUE (i) = (int) (RM_EO (&(matches[max_k]))) + (int) (LOWER_BOUND (tup)) - 1;
   }
@@ -227,19 +227,19 @@ void genie_grep_in_substring (NODE_T * p)
 
 void genie_sub_in_string (NODE_T * p)
 {
-  A68_REF ref_pat, ref_rep, ref_str;
+  A68G_REF ref_pat, ref_rep, ref_str;
   POP_REF (p, &ref_str);
   POP_REF (p, &ref_rep);
   POP_REF (p, &ref_pat);
   if (IS_NIL (ref_str)) {
-    PUSH_VALUE (p, 3, A68_INT);
+    PUSH_VALUE (p, 3, A68G_INT);
     return;
   }
   reset_transput_buffer (STRING_BUFFER);
   reset_transput_buffer (REPLACE_BUFFER);
   reset_transput_buffer (PATTERN_BUFFER);
   add_a_string_transput_buffer (p, PATTERN_BUFFER, (BYTE_T *) & ref_pat);
-  add_a_string_transput_buffer (p, STRING_BUFFER, (BYTE_T *) DEREF (A68_REF, &ref_str));
+  add_a_string_transput_buffer (p, STRING_BUFFER, (BYTE_T *) DEREF (A68G_REF, &ref_str));
   regex_t compiled;
   int ret = regcomp (&compiled, get_transput_buffer (PATTERN_BUFFER), REG_NEWLINE | REG_EXTENDED);
   if (ret != 0) {
@@ -253,7 +253,7 @@ void genie_sub_in_string (NODE_T * p)
   }
   regmatch_t *matches = a68g_alloc ((size_t) (nmatch * SIZE_ALIGNED (regmatch_t)), __func__, __LINE__);
   if (nmatch > 0 && matches == NULL) {
-    PUSH_VALUE (p, ret, A68_INT);
+    PUSH_VALUE (p, ret, A68G_INT);
     regfree (&compiled);
     return;
   }
@@ -282,7 +282,7 @@ void genie_sub_in_string (NODE_T * p)
   for (int k = end; k < get_transput_buffer_size (STRING_BUFFER); k++) {
     plusab_transput_buffer (p, REPLACE_BUFFER, txt[k]);
   }
-  *DEREF (A68_REF, &ref_str) = c_to_a_string (p, get_transput_buffer (REPLACE_BUFFER), DEFAULT_WIDTH);
+  *DEREF (A68G_REF, &ref_str) = c_to_a_string (p, get_transput_buffer (REPLACE_BUFFER), DEFAULT_WIDTH);
   a68g_free (matches);
   push_grep_ret (p, 0);
 }
