@@ -1287,7 +1287,9 @@ void mode_check_call (NODE_T * p, MOID_T * n, SOID_T * x, SOID_T * y)
       make_soid (y, SORT (x), SUB (n), 0);
     } else {
       if (OPTION_PORTCHECK (&A68G_JOB)) {
-        diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, NEXT (p), WARNING_EXTENSION);
+        diagnostic (A68G_WARNING, NEXT (p), WARNING_EXTENSION);
+      } else {
+        diagnostic (A68G_NOTICE, NEXT (p), WARNING_EXTENSION);
       }
       make_soid (y, SORT (x), PARTIAL_PROC (GINFO (p)), 0);
     }
@@ -1340,12 +1342,12 @@ void mode_check_slice (NODE_T * p, MOID_T * ori, SOID_T * x, SOID_T * y)
         }
         m = SLICE (m);
       }
-      ABEND (m == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (m == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
       subs--;
     }
 // A trim cannot be but deflexed.
     if (ANNOTATION (NEXT (p)) == TRIMMER && TRIM (m) != NO_MOID) {
-      ABEND (TRIM (m) == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (TRIM (m) == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
       make_soid (y, SORT (x), TRIM (m), 0);
     } else {
       make_soid (y, SORT (x), m, 0);
@@ -1510,7 +1512,7 @@ void mode_check_diagonal (NODE_T * p, SOID_T * x, SOID_T * y)
   } else {
     n = SLICE (n);
   }
-  ABEND (n == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (n == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   make_soid (y, SORT (x), n, 0);
 }
 
@@ -1553,7 +1555,7 @@ void mode_check_transpose (NODE_T * p, SOID_T * x, SOID_T * y)
     return;
   }
   MOID (tert) = n;
-  ABEND (n == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (n == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   make_soid (y, SORT (x), n, 0);
 }
 
@@ -1606,7 +1608,7 @@ void mode_check_row_column_function (NODE_T * p, SOID_T * x, SOID_T * y)
     return;
   }
   MOID (tert) = n;
-  ABEND (n == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (n == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   make_soid (y, SORT (x), ROWED (n), 0);
 }
 
