@@ -132,7 +132,7 @@ void plugin_driver_emit (FILE_T out)
     write_prelude (out);
     gen_units (TOP_NODE (&A68G_JOB), out);
   }
-  ABEND (A68G_OPT (indentation) != 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (A68G_OPT (indentation) != 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
 // At the end we discard temporary declarations.
   A68G (temp_heap_pointer) = pop_temp_heap_pointer;
   if (OPTION_VERBOSE (&A68G_JOB)) {
@@ -330,7 +330,7 @@ char *make_unic_name (char *buf, char *name, char *tag, char *ext)
   } else {
     ASSERT (a68g_bufprt (buf, NAME_SIZE, "genie_%s_%s", name, ext) >= 0);
   }
-  ABEND (strlen (buf) >= NAME_SIZE, ERROR_ACTION, __func__);
+  ABEND (strlen (buf) >= NAME_SIZE, ERROR_ACTION, NO_TEXT);
   return buf;
 }
 
@@ -396,7 +396,7 @@ char *make_name (char *buf, char *name, char *tag, int n)
   } else {
     ASSERT (a68g_bufprt (buf, NAME_SIZE, "genie_%s_%d", name, n) >= 0);
   }
-  ABEND (strlen (buf) >= NAME_SIZE, ERROR_ACTION, __func__);
+  ABEND (strlen (buf) >= NAME_SIZE, ERROR_ACTION, NO_TEXT);
   return buf;
 }
 
