@@ -336,7 +336,7 @@ int string_difference (NODE_T * p)
   GET_DESCRIPTOR (arr_1, tup_1, &row1);
   int len_1 = ROW_SIZE (tup_1);
 // Compute string difference.
-  int size = (len_1 > len_2 ? len_1 : len_2), diff = 0;
+  size_t size = (len_1 > len_2 ? len_1 : len_2), diff = 0;
   BYTE_T *str_1 = (len_1 > 0 ? DEREF (BYTE_T, &ARRAY (arr_1)) : NO_BYTE);
   BYTE_T *str_2 = (len_2 > 0 ? DEREF (BYTE_T, &ARRAY (arr_2)) : NO_BYTE);
   for (int k = 0; k < size && diff == 0; k++) {
@@ -384,7 +384,7 @@ void genie_elem_bytes (NODE_T * p)
   A68G_INT i;
   POP_OBJECT (p, &i, A68G_INT);
   PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68G_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  if (VALUE (&i) > (int) strlen (VALUE (&j))) {
+  if (VALUE (&i) > strlen (VALUE (&j))) {
     genie_null_char (p);
   } else {
     PUSH_VALUE (p, VALUE (&j)[VALUE (&i) - 1], A68G_CHAR);
@@ -411,7 +411,7 @@ void genie_add_bytes (NODE_T * p)
 {
   A68G_BYTES *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68G_BYTES);
-  PRELUDE_ERROR (((int) strlen (VALUE (i)) + (int) strlen (VALUE (j))) > A68G_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_BYTES);
+  PRELUDE_ERROR ((strlen (VALUE (i)) + strlen (VALUE (j))) > A68G_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_BYTES);
   a68g_bufcat (VALUE (i), VALUE (j), A68G_BYTES_WIDTH);
 }
 
@@ -433,7 +433,7 @@ void genie_plusto_bytes (NODE_T * p)
   CHECK_INIT (p, INITIALISED (address), M_BYTES);
   A68G_BYTES i;
   POP_OBJECT (p, &i, A68G_BYTES);
-  PRELUDE_ERROR (((int) strlen (VALUE (address)) + (int) strlen (VALUE (&i))) > A68G_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_BYTES);
+  PRELUDE_ERROR ((strlen (VALUE (address)) + strlen (VALUE (&i))) > A68G_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_BYTES);
   A68G_BYTES j;
   a68g_bufcpy (VALUE (&j), VALUE (&i), A68G_BYTES_WIDTH);
   a68g_bufcat (VALUE (&j), VALUE (address), A68G_BYTES_WIDTH);
@@ -496,7 +496,7 @@ void genie_elem_long_bytes (NODE_T * p)
   A68G_INT i;
   POP_OBJECT (p, &i, A68G_INT);
   PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68G_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  if (VALUE (&i) > (int) strlen (VALUE (&j))) {
+  if (VALUE (&i) > strlen (VALUE (&j))) {
     genie_null_char (p);
   } else {
     PUSH_VALUE (p, VALUE (&j)[VALUE (&i) - 1], A68G_CHAR);
@@ -523,7 +523,7 @@ void genie_add_long_bytes (NODE_T * p)
 {
   A68G_LONG_BYTES *i, *j;
   POP_OPERAND_ADDRESSES (p, i, j, A68G_LONG_BYTES);
-  PRELUDE_ERROR (((int) strlen (VALUE (i)) + (int) strlen (VALUE (j))) > A68G_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_LONG_BYTES);
+  PRELUDE_ERROR ((strlen (VALUE (i)) + strlen (VALUE (j))) > A68G_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_LONG_BYTES);
   a68g_bufcat (VALUE (i), VALUE (j), A68G_LONG_BYTES_WIDTH);
 }
 
@@ -545,7 +545,7 @@ void genie_plusto_long_bytes (NODE_T * p)
   CHECK_INIT (p, INITIALISED (address), M_LONG_BYTES);
   A68G_LONG_BYTES i;
   POP_OBJECT (p, &i, A68G_LONG_BYTES);
-  PRELUDE_ERROR (((int) strlen (VALUE (address)) + (int) strlen (VALUE (&i))) > A68G_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_LONG_BYTES);
+  PRELUDE_ERROR ((strlen (VALUE (address)) + strlen (VALUE (&i))) > A68G_LONG_BYTES_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_LONG_BYTES);
   A68G_LONG_BYTES j;
   a68g_bufcpy (VALUE (&j), VALUE (&i), A68G_LONG_BYTES_WIDTH);
   a68g_bufcat (VALUE (&j), VALUE (address), A68G_LONG_BYTES_WIDTH);
@@ -667,7 +667,7 @@ void genie_string_in_string (NODE_T * p)
       A68G_INT pos;
       STATUS (&pos) = INIT_MASK;
 // ANSI standard leaves pointer difference undefined.
-      VALUE (&pos) = LOWER_BOUND (tup) + (int) get_transput_buffer_index (STRING_BUFFER) - (int) strlen (q);
+      VALUE (&pos) = LOWER_BOUND (tup) + (int) get_transput_buffer_index (STRING_BUFFER) - strlen (q);
       *DEREF (A68G_INT, &ref_pos) = pos;
     }
     PUSH_VALUE (p, A68G_TRUE, A68G_BOOL);
