@@ -75,6 +75,7 @@ void genie_pq_connectdb (NODE_T * p)
   STATUS (file) = INIT_MASK;
   CHANNEL (file) = A68G (associate_channel);
   OPENED (file) = A68G_TRUE;
+  APPEND (file) = A68G_FALSE;
   OPEN_EXCLUSIVE (file) = A68G_FALSE;
   READ_MOOD (file) = A68G_FALSE;
   WRITE_MOOD (file) = A68G_FALSE;
@@ -87,7 +88,7 @@ void genie_pq_connectdb (NODE_T * p)
   IDENTIFICATION (file) = nil_ref;
   TERMINATOR (file) = nil_ref;
   FORMAT (file) = nil_format;
-  FD (file) = -1;
+  FD (file) = A68G_NO_FILE;
   if (INITIALISED (&(STRING (file))) && !IS_NIL (STRING (file))) {
     UNBLOCK_GC_HANDLE (&(STRING (file)));
   }
