@@ -2387,6 +2387,14 @@ A68C_TRANSPUT (long_mp_complex, long_mp_real, LONG_LONG_COMPLEX);
 
 #undef A68C_TRANSPUT
 
+void genie_peek_char (NODE_T * p)
+{
+  A68G_INT mode;
+  POP_OBJECT (p, &mode, A68G_INT);
+  CHECK_INIT (p, INITIALISED (&mode), M_INT);
+  PUSH_VALUE (p, (char) peek_char (VALUE (&mode)), A68G_CHAR);
+}
+
 //! @brief PROC STRING read line
 
 void genie_read_line (NODE_T * p)
