@@ -34,8 +34,8 @@
 
 #define PROC_RR_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x;\
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);\
+  A68G_REAL *x;\
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   int status = f (& (VALUE (x)));\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
@@ -43,8 +43,8 @@ void g (NODE_T *p) {\
 
 #define PROC_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x;\
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);\
+  A68G_REAL *x;\
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result y;\
   int status = f (VALUE (x), &y);\
@@ -54,8 +54,8 @@ void g (NODE_T *p) {\
 
 #define PROC_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x;\
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);\
+  A68G_REAL *x;\
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result y;\
   int status = f (VALUE (x), GSL_PREC_DOUBLE, &y);\
@@ -65,19 +65,19 @@ void g (NODE_T *p) {\
 
 #define PROC_I_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_INT s;\
-  POP_OBJECT (p, &s, A68_INT);\
+  A68G_INT s;\
+  POP_OBJECT (p, &s, A68G_INT);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result y;\
   int status = f (VALUE (&s), &y);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
-  PUSH_VALUE (p, VAL (&y), A68_REAL);\
+  PUSH_VALUE (p, VAL (&y), A68G_REAL);\
 }
 
 #define PROC_R_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x, *y;\
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
+  A68G_REAL *x, *y;\
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (x), VALUE (y),  &r);\
@@ -87,34 +87,34 @@ void g (NODE_T *p) {\
 
 #define PROC_I_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL x;\
-  POP_OBJECT (p, &x, A68_REAL);\
-  A68_INT s;\
-  POP_OBJECT (p, &s, A68_INT);\
+  A68G_REAL x;\
+  POP_OBJECT (p, &x, A68G_REAL);\
+  A68G_INT s;\
+  POP_OBJECT (p, &s, A68G_INT);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (&s), VALUE (&x), &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
-  PUSH_VALUE (p, VAL (&r), A68_REAL);\
+  PUSH_VALUE (p, VAL (&r), A68G_REAL);\
 }
 
 #define PROC_I_R_R_REVERSED(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL x;\
-  POP_OBJECT (p, &x, A68_REAL);\
-  A68_INT s;\
-  POP_OBJECT (p, &s, A68_INT);\
+  A68G_REAL x;\
+  POP_OBJECT (p, &x, A68G_REAL);\
+  A68G_INT s;\
+  POP_OBJECT (p, &s, A68G_INT);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (&x), VALUE (&s), &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
-  PUSH_VALUE (p, VAL (&r), A68_REAL);\
+  PUSH_VALUE (p, VAL (&r), A68G_REAL);\
 }
 
 #define PROC_R_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x, *y;\
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
+  A68G_REAL *x, *y;\
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (x), VALUE (y), GSL_PREC_DOUBLE, &r);\
@@ -124,9 +124,9 @@ void g (NODE_T *p) {\
 
 #define PROC_R_R_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x, *y, *z;\
-  POP_ADDRESS (p, z, A68_REAL);\
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
+  A68G_REAL *x, *y, *z;\
+  POP_ADDRESS (p, z, A68G_REAL);\
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (x), VALUE (y), VALUE (z),  &r);\
@@ -136,23 +136,23 @@ void g (NODE_T *p) {\
 
 #define PROC_I_R_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL x, y;\
-  POP_OBJECT (p, &y, A68_REAL);\
-  POP_OBJECT (p, &x, A68_REAL);\
-  A68_INT s;\
-  POP_OBJECT (p, &s, A68_INT);\
+  A68G_REAL x, y;\
+  POP_OBJECT (p, &y, A68G_REAL);\
+  POP_OBJECT (p, &x, A68G_REAL);\
+  A68G_INT s;\
+  POP_OBJECT (p, &s, A68G_INT);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (&s), VALUE (&x), VALUE (&y), &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
-  PUSH_VALUE (p, VAL (&r), A68_REAL);\
+  PUSH_VALUE (p, VAL (&r), A68G_REAL);\
 }
 
 #define PROC_R_R_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x, *y, *z;\
-  POP_ADDRESS (p, z, A68_REAL);\
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
+  A68G_REAL *x, *y, *z;\
+  POP_ADDRESS (p, z, A68G_REAL);\
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (x), VALUE (y), VALUE (z), GSL_PREC_DOUBLE, &r);\
@@ -162,10 +162,10 @@ void g (NODE_T *p) {\
 
 #define PROC_R_R_R_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68_REAL *x, *y, *z, *rho;\
-  POP_ADDRESS (p, rho, A68_REAL);\
-  POP_ADDRESS (p, z, A68_REAL);\
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
+  A68G_REAL *x, *y, *z, *rho;\
+  POP_ADDRESS (p, rho, A68G_REAL);\
+  POP_ADDRESS (p, z, A68G_REAL);\
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);\
   (void) gsl_set_error_handler_off ();\
   gsl_sf_result r;\
   int status = f (VALUE (x), VALUE (y), VALUE (z), VALUE (rho), GSL_PREC_DOUBLE, &r);\
