@@ -27,7 +27,7 @@
 
 // This file contains bindings to the GNU R standalone mathematical library.
 
-#if defined (HAVE_MATHLIB)
+#if defined (HAVE_R_MATHLIB)
 
 #include "a68g-genie.h"
 #include "a68g-prelude.h"
@@ -65,8 +65,8 @@ void genie_R_pentagamma_real (NODE_T * p)
 
 void genie_R_psigamma_real (NODE_T * p)
 {
-  A68_REAL *x, *s;
-  POP_OPERAND_ADDRESSES (p, x, s, A68_REAL);
+  A68G_REAL *x, *s;
+  POP_OPERAND_ADDRESSES (p, x, s, A68G_REAL);
   errno = 0;
   VALUE (x) = psigamma (VALUE (x), (int) VALUE (s));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
@@ -75,129 +75,129 @@ void genie_R_psigamma_real (NODE_T * p)
 #define D_3(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_BOOL give_log;\
-  A68_REAL a, b;\
-  POP_OBJECT (p, &give_log, A68_BOOL);\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
+  A68G_BOOL give_log;\
+  A68G_REAL a, b;\
+  POP_OBJECT (p, &give_log, A68G_BOOL);\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
   errno = 0;\
   PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b),\
-                       (VALUE (&give_log) == A68_TRUE ? 1 : 0)), A68_REAL);\
+                       (VALUE (&give_log) == A68G_TRUE ? 1 : 0)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define D_4(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_BOOL give_log;\
-  A68_REAL a, b, c;\
-  POP_OBJECT (p, &give_log, A68_BOOL);\
-  POP_OBJECT (p, &c, A68_REAL);\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
+  A68G_BOOL give_log;\
+  A68G_REAL a, b, c;\
+  POP_OBJECT (p, &give_log, A68G_BOOL);\
+  POP_OBJECT (p, &c, A68G_REAL);\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
   errno = 0;\
   PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b), VALUE (&c),\
-                       (VALUE (&give_log) == A68_TRUE ? 1 : 0)), A68_REAL);\
+                       (VALUE (&give_log) == A68G_TRUE ? 1 : 0)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define D_5(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_BOOL give_log;\
-  A68_REAL a, b, c, d;\
-  POP_OBJECT (p, &give_log, A68_BOOL);\
-  POP_OBJECT (p, &d, A68_REAL);\
-  POP_OBJECT (p, &c, A68_REAL);\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
+  A68G_BOOL give_log;\
+  A68G_REAL a, b, c, d;\
+  POP_OBJECT (p, &give_log, A68G_BOOL);\
+  POP_OBJECT (p, &d, A68G_REAL);\
+  POP_OBJECT (p, &c, A68G_REAL);\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
   errno = 0;\
   PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b), VALUE (&c), VALUE (&d),\
-                       (VALUE (&give_log) == A68_TRUE ? 1 : 0)), A68_REAL);\
+                       (VALUE (&give_log) == A68G_TRUE ? 1 : 0)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define PQ_4(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_BOOL lower_tail, log_p;\
-  A68_REAL x, a;\
-  POP_OBJECT (p, &log_p, A68_BOOL);\
-  POP_OBJECT (p, &lower_tail, A68_BOOL);\
-  POP_OBJECT (p, &a, A68_REAL);\
-  POP_OBJECT (p, &x, A68_REAL);\
+  A68G_BOOL lower_tail, log_p;\
+  A68G_REAL x, a;\
+  POP_OBJECT (p, &log_p, A68G_BOOL);\
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
+  POP_OBJECT (p, &x, A68G_REAL);\
   errno = 0;\
   PUSH_VALUE (p, R_fun (VALUE (&x), VALUE (&a),\
-              (VALUE (&lower_tail) == A68_TRUE ? 1 : 0),\
-              (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);\
+              (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0),\
+              (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define PQ_5(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_BOOL lower_tail, log_p;\
-  A68_REAL x, a, b;\
-  POP_OBJECT (p, &log_p, A68_BOOL);\
-  POP_OBJECT (p, &lower_tail, A68_BOOL);\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
-  POP_OBJECT (p, &x, A68_REAL);\
+  A68G_BOOL lower_tail, log_p;\
+  A68G_REAL x, a, b;\
+  POP_OBJECT (p, &log_p, A68G_BOOL);\
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
+  POP_OBJECT (p, &x, A68G_REAL);\
   errno = 0;\
   PUSH_VALUE (p, R_fun (VALUE (&x), VALUE (&a), VALUE (&b),\
-              (VALUE (&lower_tail) == A68_TRUE ? 1 : 0),\
-              (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);\
+              (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0),\
+              (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define PQ_6(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_BOOL lower_tail, log_p;\
-  A68_REAL x, a, b, c;\
-  POP_OBJECT (p, &log_p, A68_BOOL);\
-  POP_OBJECT (p, &lower_tail, A68_BOOL);\
-  POP_OBJECT (p, &c, A68_REAL);\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
-  POP_OBJECT (p, &x, A68_REAL);\
+  A68G_BOOL lower_tail, log_p;\
+  A68G_REAL x, a, b, c;\
+  POP_OBJECT (p, &log_p, A68G_BOOL);\
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);\
+  POP_OBJECT (p, &c, A68G_REAL);\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
+  POP_OBJECT (p, &x, A68G_REAL);\
   errno = 0;\
   PUSH_VALUE (p, R_fun (VALUE (&x), VALUE (&a), VALUE (&b), VALUE (&c),\
-              (VALUE (&lower_tail) == A68_TRUE ? 1 : 0),\
-              (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);\
+              (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0),\
+              (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define R_1(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_REAL a;\
-  POP_OBJECT (p, &a, A68_REAL);\
+  A68G_REAL a;\
+  POP_OBJECT (p, &a, A68G_REAL);\
   errno = 0;\
-  PUSH_VALUE (p, R_fun (VALUE (&a)), A68_REAL);\
+  PUSH_VALUE (p, R_fun (VALUE (&a)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define R_2(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_REAL a, b;\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
+  A68G_REAL a, b;\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
   errno = 0;\
-  PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b)), A68_REAL);\
+  PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
 #define R_3(a68g_fun, R_fun)\
 void a68g_fun (NODE_T * p)\
 {\
-  A68_REAL a, b, c;\
-  POP_OBJECT (p, &c, A68_REAL);\
-  POP_OBJECT (p, &b, A68_REAL);\
-  POP_OBJECT (p, &a, A68_REAL);\
+  A68G_REAL a, b, c;\
+  POP_OBJECT (p, &c, A68G_REAL);\
+  POP_OBJECT (p, &b, A68G_REAL);\
+  POP_OBJECT (p, &a, A68G_REAL);\
   errno = 0;\
-  PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b), VALUE (&c)), A68_REAL);\
+  PUSH_VALUE (p, R_fun (VALUE (&a), VALUE (&b), VALUE (&c)), A68G_REAL);\
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);\
 }
 
@@ -444,47 +444,47 @@ PQ_6 (genie_R_qtukey_real, qtukey);
 
 void genie_R_dwilcox_real (NODE_T * p)
 {
-  A68_BOOL give_log;
-  A68_REAL a, b, c;
+  A68G_BOOL give_log;
+  A68G_REAL a, b, c;
   extern void wilcox_free (void);
-  POP_OBJECT (p, &give_log, A68_BOOL);
-  POP_OBJECT (p, &c, A68_REAL);
-  POP_OBJECT (p, &b, A68_REAL);
-  POP_OBJECT (p, &a, A68_REAL);
+  POP_OBJECT (p, &give_log, A68G_BOOL);
+  POP_OBJECT (p, &c, A68G_REAL);
+  POP_OBJECT (p, &b, A68G_REAL);
+  POP_OBJECT (p, &a, A68G_REAL);
   errno = 0;
-  PUSH_VALUE (p, dwilcox (VALUE (&a), VALUE (&b), VALUE (&c), (VALUE (&give_log) == A68_TRUE ? 1 : 0)), A68_REAL);
+  PUSH_VALUE (p, dwilcox (VALUE (&a), VALUE (&b), VALUE (&c), (VALUE (&give_log) == A68G_TRUE ? 1 : 0)), A68G_REAL);
   wilcox_free ();
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
 void genie_R_pwilcox_real (NODE_T * p)
 {
-  A68_BOOL lower_tail, log_p;
-  A68_REAL x, a, b;
+  A68G_BOOL lower_tail, log_p;
+  A68G_REAL x, a, b;
   extern void wilcox_free (void);
-  POP_OBJECT (p, &log_p, A68_BOOL);
-  POP_OBJECT (p, &lower_tail, A68_BOOL);
-  POP_OBJECT (p, &b, A68_REAL);
-  POP_OBJECT (p, &a, A68_REAL);
-  POP_OBJECT (p, &x, A68_REAL);
+  POP_OBJECT (p, &log_p, A68G_BOOL);
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);
+  POP_OBJECT (p, &b, A68G_REAL);
+  POP_OBJECT (p, &a, A68G_REAL);
+  POP_OBJECT (p, &x, A68G_REAL);
   errno = 0;
-  PUSH_VALUE (p, pwilcox (VALUE (&x), VALUE (&a), VALUE (&b), (VALUE (&lower_tail) == A68_TRUE ? 1 : 0), (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);
+  PUSH_VALUE (p, pwilcox (VALUE (&x), VALUE (&a), VALUE (&b), (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0), (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);
   wilcox_free ();
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
 void genie_R_qwilcox_real (NODE_T * p)
 {
-  A68_BOOL lower_tail, log_p;
-  A68_REAL x, a, b;
+  A68G_BOOL lower_tail, log_p;
+  A68G_REAL x, a, b;
   extern void wilcox_free (void);
-  POP_OBJECT (p, &log_p, A68_BOOL);
-  POP_OBJECT (p, &lower_tail, A68_BOOL);
-  POP_OBJECT (p, &b, A68_REAL);
-  POP_OBJECT (p, &a, A68_REAL);
-  POP_OBJECT (p, &x, A68_REAL);
+  POP_OBJECT (p, &log_p, A68G_BOOL);
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);
+  POP_OBJECT (p, &b, A68G_REAL);
+  POP_OBJECT (p, &a, A68G_REAL);
+  POP_OBJECT (p, &x, A68G_REAL);
   errno = 0;
-  PUSH_VALUE (p, qwilcox (VALUE (&x), VALUE (&a), VALUE (&b), (VALUE (&lower_tail) == A68_TRUE ? 1 : 0), (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);
+  PUSH_VALUE (p, qwilcox (VALUE (&x), VALUE (&a), VALUE (&b), (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0), (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);
   wilcox_free ();
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
@@ -500,44 +500,44 @@ R_2 (genie_R_rwilcox_real, rwilcox);
 
 void genie_R_dsignrank_real (NODE_T * p)
 {
-  A68_BOOL give_log;
-  A68_REAL a, b;
+  A68G_BOOL give_log;
+  A68G_REAL a, b;
   extern void signrank_free (void);
-  POP_OBJECT (p, &give_log, A68_BOOL);
-  POP_OBJECT (p, &b, A68_REAL);
-  POP_OBJECT (p, &a, A68_REAL);
+  POP_OBJECT (p, &give_log, A68G_BOOL);
+  POP_OBJECT (p, &b, A68G_REAL);
+  POP_OBJECT (p, &a, A68G_REAL);
   errno = 0;
-  PUSH_VALUE (p, dsignrank (VALUE (&a), VALUE (&b), (VALUE (&give_log) == A68_TRUE ? 1 : 0)), A68_REAL);
+  PUSH_VALUE (p, dsignrank (VALUE (&a), VALUE (&b), (VALUE (&give_log) == A68G_TRUE ? 1 : 0)), A68G_REAL);
   signrank_free ();
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
 void genie_R_psignrank_real (NODE_T * p)
 {
-  A68_BOOL lower_tail, log_p;
-  A68_REAL x, a;
+  A68G_BOOL lower_tail, log_p;
+  A68G_REAL x, a;
   extern void signrank_free (void);
-  POP_OBJECT (p, &log_p, A68_BOOL);
-  POP_OBJECT (p, &lower_tail, A68_BOOL);
-  POP_OBJECT (p, &a, A68_REAL);
-  POP_OBJECT (p, &x, A68_REAL);
+  POP_OBJECT (p, &log_p, A68G_BOOL);
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);
+  POP_OBJECT (p, &a, A68G_REAL);
+  POP_OBJECT (p, &x, A68G_REAL);
   errno = 0;
-  PUSH_VALUE (p, psignrank (VALUE (&x), VALUE (&a), (VALUE (&lower_tail) == A68_TRUE ? 1 : 0), (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);
+  PUSH_VALUE (p, psignrank (VALUE (&x), VALUE (&a), (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0), (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);
   signrank_free ();
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
 
 void genie_R_qsignrank_real (NODE_T * p)
 {
-  A68_BOOL lower_tail, log_p;
-  A68_REAL x, a;
+  A68G_BOOL lower_tail, log_p;
+  A68G_REAL x, a;
   extern void signrank_free (void);
-  POP_OBJECT (p, &log_p, A68_BOOL);
-  POP_OBJECT (p, &lower_tail, A68_BOOL);
-  POP_OBJECT (p, &a, A68_REAL);
-  POP_OBJECT (p, &x, A68_REAL);
+  POP_OBJECT (p, &log_p, A68G_BOOL);
+  POP_OBJECT (p, &lower_tail, A68G_BOOL);
+  POP_OBJECT (p, &a, A68G_REAL);
+  POP_OBJECT (p, &x, A68G_REAL);
   errno = 0;
-  PUSH_VALUE (p, qsignrank (VALUE (&x), VALUE (&a), (VALUE (&lower_tail) == A68_TRUE ? 1 : 0), (VALUE (&log_p) == A68_TRUE ? 1 : 0)), A68_REAL);
+  PUSH_VALUE (p, qsignrank (VALUE (&x), VALUE (&a), (VALUE (&lower_tail) == A68G_TRUE ? 1 : 0), (VALUE (&log_p) == A68G_TRUE ? 1 : 0)), A68G_REAL);
   signrank_free ();
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
 }
