@@ -461,13 +461,16 @@ void genie_matrix_det (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_matrix *u = pop_matrix (p, A68G_TRUE);
   gsl_permutation *q = gsl_permutation_calloc (SIZE1 (u));
-  int sign;
-  ASSERT_GSL (gsl_linalg_LU_decomp (u, q, &sign));
-  REAL_T det = gsl_linalg_LU_det (u, sign);
-  if (a68g_isnan_real (det)) { // Singularity.
+  int sign, rc = gsl_linalg_LU_decomp (u, q, &sign);
+  if (rc != GSL_SUCCESS) {
     PUSH_VALUE (p, 0, A68G_REAL);
   } else {
-    PUSH_VALUE (p, gsl_linalg_LU_det (u, sign), A68G_REAL);
+    REAL_T det = gsl_linalg_LU_det (u, sign);
+    if (a68g_isnan_real (det)) {
+      PUSH_VALUE (p, 0, A68G_REAL);
+    } else {
+      PUSH_VALUE (p, det, A68G_REAL);
+    }
   }
   gsl_matrix_free (u);
   gsl_permutation_free (q);
@@ -481,20 +484,20 @@ void genie_matrix_complex_det (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_matrix_complex *u = pop_matrix_complex (p, A68G_TRUE);
   gsl_permutation *q = gsl_permutation_calloc (SIZE1 (u));
-  int sign;
-  ASSERT_GSL (gsl_linalg_complex_LU_decomp (u, q, &sign));
-  gsl_complex det = gsl_linalg_complex_LU_det (u, sign);
-  REAL_T re_det = GSL_REAL (det);
-  if (a68g_isnan_real (re_det)) { // Singularity.
+  int sign, rc = gsl_linalg_complex_LU_decomp (u, q, &sign);
+  if (rc != GSL_SUCCESS) {
+    PUSH_VALUE (p, 0, A68G_REAL);
     PUSH_VALUE (p, 0, A68G_REAL);
   } else {
-    PUSH_VALUE (p, re_det, A68G_REAL);
-  }
-  REAL_T im_det = GSL_IMAG (det);
-  if (a68g_isnan_real (im_det)) { // Singularity.
-    PUSH_VALUE (p, 0, A68G_REAL);
-  } else {
-    PUSH_VALUE (p, im_det, A68G_REAL);
+    gsl_complex det = gsl_linalg_complex_LU_det (u, sign);
+    REAL_T re_det = GSL_REAL (det), im_det = GSL_IMAG (det);
+    if (a68g_isnan_real (re_det) || a68g_isnan_real (im_det)) {
+      PUSH_VALUE (p, 0, A68G_REAL);
+      PUSH_VALUE (p, 0, A68G_REAL);
+    } else {
+      PUSH_VALUE (p, re_det, A68G_REAL);
+      PUSH_VALUE (p, im_det, A68G_REAL);
+    }
   }
   gsl_matrix_complex_free (u);
   gsl_permutation_free (q);
