@@ -37,7 +37,7 @@
 #define MP_DIGIT(z, n) ((z)[(n) + 1])
 #define MP_SIGN(z) (SIGN (MP_DIGIT (z, 1)))
 #define LEN_MP(digs) (2 + digs)
-#define SIZE_MP(digs) A68_ALIGN (LEN_MP (digs) * sizeof (MP_T))
+#define SIZE_MP(digs) A68G_ALIGN (LEN_MP (digs) * sizeof (MP_T))
 #define IS_ZERO_MP(z) (MP_DIGIT (z, 1) == (MP_T) 0)
 
 #define PLUS_INF_MP(u) ((UNSIGNED_T) MP_STATUS (u) & PLUS_INF_MASK)
@@ -78,31 +78,31 @@ static inline void check_mp_exp (NODE_T *p, MP_T *z)
   MP_T expo = (MP_EXPONENT (z) < 0 ? -MP_EXPONENT (z) : MP_EXPONENT (z));
   if (expo > MAX_MP_EXPONENT || (expo == MAX_MP_EXPONENT && ABS (MP_DIGIT (z, 1)) > (MP_T) 1)) {
     errno = EDOM;
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_MP_OUT_OF_BOUNDS, NULL);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MP_OUT_OF_BOUNDS, NULL);
     extern void exit_genie (NODE_T *, int);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 }
 
 static inline MP_T *mp_one (int digs)
 {
-  if (digs > A68_MP (mp_one_size)) {
-    if (A68_MP (mp_one) != (MP_T *) NULL) {
-      a68g_free (A68_MP (mp_one));
+  if (digs > A68G_MP (mp_one_size)) {
+    if (A68G_MP (mp_one) != (MP_T *) NULL) {
+      a68g_free (A68G_MP (mp_one));
     }
-    A68_MP (mp_one) = (MP_T *) get_heap_space (SIZE_MP (digs));
-    set_mp (A68_MP (mp_one), 1, 0, digs);
+    A68G_MP (mp_one) = (MP_T *) get_heap_space (SIZE_MP (digs));
+    set_mp (A68G_MP (mp_one), 1, 0, digs);
   }
-  return A68_MP (mp_one);
+  return A68G_MP (mp_one);
 }
 
 static inline MP_T *lit_mp (NODE_T *p, MP_T u, INT_T expo, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
-  if ((A68_SP += SIZE_MP (digs)) > A68 (expr_stack_limit)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
+  ADDR_T pop_sp = A68G_SP;
+  if ((A68G_SP += SIZE_MP (digs)) > A68G (expr_stack_limit)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
     extern void exit_genie (NODE_T *, int);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   MP_T *z = (MP_T *) STACK_ADDRESS (pop_sp);
   (void) set_mp (z, u, expo, digs);
@@ -111,11 +111,11 @@ static inline MP_T *lit_mp (NODE_T *p, MP_T u, INT_T expo, int digs)
 
 static inline MP_T *nil_mp (NODE_T *p, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
-  if ((A68_SP += SIZE_MP (digs)) > A68 (expr_stack_limit)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
+  ADDR_T pop_sp = A68G_SP;
+  if ((A68G_SP += SIZE_MP (digs)) > A68G (expr_stack_limit)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
     extern void exit_genie (NODE_T *, int);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   MP_T *z = (MP_T *) STACK_ADDRESS (pop_sp);
   (void) set_mp (z, 0, 0, digs);
@@ -124,11 +124,11 @@ static inline MP_T *nil_mp (NODE_T *p, int digs)
 
 static inline MP_T *empty_mp (NODE_T *p, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
-  if ((A68_SP += SIZE_MP (digs)) > A68 (expr_stack_limit)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
+  ADDR_T pop_sp = A68G_SP;
+  if ((A68G_SP += SIZE_MP (digs)) > A68G (expr_stack_limit)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
     extern void exit_genie (NODE_T *, int);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   return (MP_T *) STACK_ADDRESS (pop_sp);
 }
@@ -137,11 +137,11 @@ extern MP_T *lengthen_mp (NODE_T *, MP_T *, int, MP_T *, int);
 
 static inline MP_T *len_mp (NODE_T *p, MP_T *u, int digs, int gdigs)
 {
-  ADDR_T pop_sp = A68_SP;
-  if ((A68_SP += SIZE_MP (gdigs)) > A68 (expr_stack_limit)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
+  ADDR_T pop_sp = A68G_SP;
+  if ((A68G_SP += SIZE_MP (gdigs)) > A68G (expr_stack_limit)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
     extern void exit_genie (NODE_T *, int);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   MP_T *z = (MP_T *) STACK_ADDRESS (pop_sp);
   for (int k = 1; k <= digs; k++) {
@@ -157,13 +157,13 @@ static inline MP_T *len_mp (NODE_T *p, MP_T *u, int digs, int gdigs)
 
 static inline MP_T *cut_mp (NODE_T *p, MP_T *u, int digs, int gdigs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   ASSERT (digs > gdigs);
   BOOL_T neg = MP_DIGIT (u, 1) < 0;
-  if ((A68_SP += SIZE_MP (gdigs)) > A68 (expr_stack_limit)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
+  if ((A68G_SP += SIZE_MP (gdigs)) > A68G (expr_stack_limit)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
     extern void exit_genie (NODE_T *, int);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   MP_T *z = (MP_T *) STACK_ADDRESS (pop_sp);
   for (int k = 1; k <= gdigs; k++) {
@@ -205,14 +205,14 @@ static inline int mp_digits (void)
 
 static inline size_t size_long_mp (void)
 {
-  return (size_t) (SIZE_MP (A68_MP (varying_mp_digits)));
+  return (size_t) (SIZE_MP (A68G_MP (varying_mp_digits)));
 }
 
 //! @brief digits in a long mp number.
 
 static inline int long_mp_digits (void)
 {
-  return A68_MP (varying_mp_digits);
+  return A68G_MP (varying_mp_digits);
 }
 
 #define SET_MP_ZERO(z, digits)\
@@ -244,9 +244,9 @@ enum {MP_SQRT_PI, MP_PI, MP_LN_PI, MP_SQRT_TWO_PI, MP_TWO_PI, MP_HALF_PI, MP_180
 // GUARD_DIGITS: number of guard digits.
 
 #if defined (MP_DOUBLE_PRECISION)
-#define GUARD_DIGITS(digits) (digits)
+  #define GUARD_DIGITS(digits) (digits)
 #else
-#define GUARD_DIGITS(digits) (2)
+  #define GUARD_DIGITS(digits) (2)
 #endif
 
 #define FUN_DIGITS(n) ((n) + GUARD_DIGITS (n))
@@ -363,13 +363,13 @@ MP_T *tenth_mp (NODE_T *, MP_T *, MP_T *, int);
 MP_T *trunc_mp (NODE_T *, MP_T *, MP_T *, int);
 MP_T *unt_to_mp (NODE_T *, MP_T *, UNSIGNED_T, int);
 REAL_T mp_to_real (NODE_T *, MP_T *, int);
-void eq_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
-void ge_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
+void eq_mp (NODE_T *, A68G_BOOL *, MP_T *, MP_T *, int);
+void ge_mp (NODE_T *, A68G_BOOL *, MP_T *, MP_T *, int);
 void genie_pi_mp (NODE_T *);
-void gt_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
-void le_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
-void lt_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
-void ne_mp (NODE_T *, A68_BOOL *, MP_T *, MP_T *, int);
+void gt_mp (NODE_T *, A68G_BOOL *, MP_T *, MP_T *, int);
+void le_mp (NODE_T *, A68G_BOOL *, MP_T *, MP_T *, int);
+void lt_mp (NODE_T *, A68G_BOOL *, MP_T *, MP_T *, int);
+void ne_mp (NODE_T *, A68G_BOOL *, MP_T *, MP_T *, int);
 void raw_write_mp (char *, MP_T *, int);
 void set_long_mp_digits (int);
 void test_mp_int_range (NODE_T *, MP_T *, MOID_T *);
@@ -548,27 +548,27 @@ GPROC genie_timesab_mp_complex;
 GPROC genie_xor_mp;
 
 #if defined (HAVE_GNU_MPFR)
-GPROC genie_beta_inc_mpfr;
-GPROC genie_ln_beta_mpfr;
-GPROC genie_beta_mpfr;
-GPROC genie_gamma_inc_mpfr;
-GPROC genie_gamma_inc_real_mpfr;
-GPROC genie_gamma_inc_double_mpfr;
-GPROC genie_gamma_mpfr;
-GPROC genie_lngamma_mpfr;
-GPROC genie_mpfr_erfc_mp;
-GPROC genie_mpfr_erf_mp;
-GPROC genie_mpfr_inverfc_mp;
-GPROC genie_mpfr_inverf_mp;
-GPROC genie_mpfr_mp;
-size_t mpfr_digits (void);
+  GPROC genie_beta_inc_mpfr;
+  GPROC genie_ln_beta_mpfr;
+  GPROC genie_beta_mpfr;
+  GPROC genie_gamma_inc_mpfr;
+  GPROC genie_gamma_inc_real_mpfr;
+  GPROC genie_gamma_inc_double_mpfr;
+  GPROC genie_gamma_mpfr;
+  GPROC genie_lngamma_mpfr;
+  GPROC genie_mpfr_erfc_mp;
+  GPROC genie_mpfr_erf_mp;
+  GPROC genie_mpfr_inverfc_mp;
+  GPROC genie_mpfr_inverf_mp;
+  GPROC genie_mpfr_mp;
+  size_t mpfr_digits (void);
 #endif
 
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
 GPROC genie_quad_mp;
 #endif
 
-#if (A68_LEVEL <= 2)
+#if (A68G_LEVEL <= 2)
 int get_mp_bits_width (const MOID_T *);
 int get_mp_bits_words (const MOID_T *);
 MP_BITS_T *stack_mp_bits (NODE_T *, MP_T *, MOID_T *);
